km3pipe.db.DOM
==============

.. currentmodule:: km3pipe.db

.. autoclass:: DOM

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DOM.__init__
      ~DOM.from_json
   
   

   
   
   